[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]
[or-cvs] r9694: Twiddle constants wrt uploading hidden service descriptors. (in tor/trunk: . src/or)
- To: or-cvs@xxxxxxxxxxxxx
- Subject: [or-cvs] r9694: Twiddle constants wrt uploading hidden service descriptors. (in tor/trunk: . src/or)
- From: nickm@xxxxxxxx
- Date: Wed, 28 Feb 2007 19:41:30 -0500 (EST)
- Delivered-to: archiver@seul.org
- Delivered-to: or-cvs-outgoing@seul.org
- Delivered-to: or-cvs@seul.org
- Delivery-date: Wed, 28 Feb 2007 19:41:38 -0500
- Reply-to: or-talk@xxxxxxxxxxxxx
- Sender: owner-or-cvs@xxxxxxxxxxxxx
Author: nickm
Date: 2007-02-28 19:41:28 -0500 (Wed, 28 Feb 2007)
New Revision: 9694
Modified:
tor/trunk/
tor/trunk/ChangeLog
tor/trunk/src/or/config.c
tor/trunk/src/or/rendservice.c
Log:
r12012@catbus: nickm | 2007-02-28 18:25:18 -0500
Twiddle constants wrt uploading hidden service descriptors.
Property changes on: tor/trunk
___________________________________________________________________
svk:merge ticket from /tor/trunk [r12012] on 8246c3cf-6607-4228-993b-4d95d33730f1
Modified: tor/trunk/ChangeLog
===================================================================
--- tor/trunk/ChangeLog 2007-03-01 00:41:25 UTC (rev 9693)
+++ tor/trunk/ChangeLog 2007-03-01 00:41:28 UTC (rev 9694)
@@ -13,6 +13,10 @@
uptime and bandwidth cutoffs.
- Stop listing hibernating servers in the v1 directory.
+ o Minor bugfixes (hidden services):
+ - Upload hidden service descriptors slightly less often, to reduce
+ load on authorities.
+
o Minor bugfixes (other):
- Fix an assert that could trigger if a controller quickly set then
cleared EntryNodes. (Bug found by Udo van den Heuvel.)
Modified: tor/trunk/src/or/config.c
===================================================================
--- tor/trunk/src/or/config.c 2007-03-01 00:41:25 UTC (rev 9693)
+++ tor/trunk/src/or/config.c 2007-03-01 00:41:28 UTC (rev 9694)
@@ -2272,7 +2272,7 @@
/** Lowest allowable value for RendPostPeriod; if this is too low, hidden
* services can overload the directory system. */
-#define MIN_REND_POST_PERIOD (5*60)
+#define MIN_REND_POST_PERIOD (10*60)
/** Highest allowable value for RendPostPeriod. */
#define MAX_DIR_PERIOD (MIN_ONION_KEY_LIFETIME/2)
Modified: tor/trunk/src/or/rendservice.c
===================================================================
--- tor/trunk/src/or/rendservice.c 2007-03-01 00:41:25 UTC (rev 9693)
+++ tor/trunk/src/or/rendservice.c 2007-03-01 00:41:28 UTC (rev 9694)
@@ -1091,9 +1091,9 @@
}
if (service->next_upload_time < now ||
(service->desc_is_dirty &&
- service->desc_is_dirty < now-5)) {
+ service->desc_is_dirty < now-30)) {
/* if it's time, or if the directory servers have a wrong service
* descriptor and ours has been stable for 5 seconds, upload a
* new one of each format. */
upload_service_descriptor(service, 0);
service->next_upload_time = now + rendpostperiod;
@@ -1091,9 +1091,9 @@
/* if it's time, or if the directory servers have a wrong service
- * descriptor and ours has been stable for 5 seconds, upload a
+ * descriptor and ours has been stable for 30 seconds, upload a
* new one of each format. */
upload_service_descriptor(service, 0);